import { CalendarNavigationButton } from './chunk-Y3LX6YW4.mjs';
import { useCurrentLocale } from './chunk-KHLKL74E.mjs';
import { Flex } from '@chakra-ui/react';
import { getLocalTimeZone } from '@internationalized/date';
import { createTexts, useTranslation } from '@vygruppen/spor-i18n-react';
import { ArrowLeftOutline24Icon, ArrowRightOutline24Icon } from '@vygruppen/spor-icon-react';
import { Heading } from '@vygruppen/spor-typography-react';
import React from 'react';

function CalendarHeader({
  state,
  showYearNavigation = false,
  title
}) {
  const locale = useCurrentLocale();
  const monthFormatter = Intl.DateTimeFormat(locale, {
    month: "long"
  });
  const jsDate = state.focusedDate.toDate(getLocalTimeZone());
  const monthTitle = monthFormatter.format(jsDate);
  const monthAndYearTitle = `${monthTitle} ${state.focusedDate.year}`;
  const isPreviousYearDisabled = state.isInvalid(
    state.visibleRange.start.subtract({ years: 1 })
  );
  const isNextYearDisabled = state.isInvalid(
    state.visibleRange.start.add({ years: 1 })
  );
  const areAllOtherYearsDisabled = isPreviousYearDisabled && isNextYearDisabled;
  const isYearPickerVisible = showYearNavigation && !areAllOtherYearsDisabled;
  return /* @__PURE__ */ React.createElement(Flex, { alignItems: "center", paddingBottom: "4", justifyContent: "space-between" }, /* @__PURE__ */ React.createElement(
    CalendarNavigator,
    {
      title: title ? title : isYearPickerVisible ? monthTitle : monthAndYearTitle,
      unit: "month",
      onPrevious: () => state.setFocusedDate(state.focusedDate.subtract({ months: 1 })),
      onNext: () => state.setFocusedDate(state.focusedDate.add({ months: 1 })),
      isNextDisabled: !state.isPreviousVisibleRangeInvalid,
      isPreviousDisabled: !state.isNextVisibleRangeInvalid
    }
  ), isYearPickerVisible && /* @__PURE__ */ React.createElement(
    CalendarNavigator,
    {
      title: jsDate.getFullYear().toString(),
      unit: "year",
      onPrevious: () => state.setFocusedDate(state.focusedDate.subtract({ years: 1 })),
      onNext: () => state.setFocusedDate(state.focusedDate.add({ years: 1 })),
      isPreviousDisabled: isPreviousYearDisabled,
      isNextDisabled: isNextYearDisabled
    }
  ));
}
var capitalize = (str = "") => str.charAt(0).toUpperCase() + str.slice(1);
var CalendarNavigator = ({
  title,
  unit,
  onPrevious,
  isPreviousDisabled,
  onNext,
  isNextDisabled
}) => {
  const { t } = useTranslation();
  return /* @__PURE__ */ React.createElement(Flex, { alignItems: "center", flexGrow: 1 }, /* @__PURE__ */ React.createElement(
    CalendarNavigationButton,
    {
      onPress: onPrevious,
      isDisabled: isPreviousDisabled,
      icon: /* @__PURE__ */ React.createElement(ArrowLeftOutline24Icon, null),
      "aria-label": `${t(texts.previous)} ${t(texts[unit])}`
    }
  ), /* @__PURE__ */ React.createElement(
    Heading,
    {
      as: "div",
      role: "heading",
      variant: "sm",
      fontWeight: "bold",
      flex: "1",
      textAlign: "center"
    },
    capitalize(title)
  ), /* @__PURE__ */ React.createElement(
    CalendarNavigationButton,
    {
      onPress: onNext,
      isDisabled: isNextDisabled,
      icon: /* @__PURE__ */ React.createElement(ArrowRightOutline24Icon, null),
      "aria-label": `${t(texts.next)} ${t(texts[unit])}`
    }
  ));
};
var texts = createTexts({
  previous: {
    nb: "Forrige",
    nn: "Forrige",
    sv: "F\xF6reg\xE5ende",
    en: "Previous"
  },
  next: {
    nb: "Neste",
    nn: "Neste",
    sv: "N\xE4sta",
    en: "Next"
  },
  month: {
    nb: "m\xE5ned",
    nn: "m\xE5nad",
    sv: "m\xE5nad",
    en: "month"
  },
  year: {
    nb: "\xE5r",
    nn: "\xE5r",
    sv: "\xE5r",
    en: "year"
  }
});

export { CalendarHeader, CalendarNavigator };
