import { TimeField } from './chunk-Y3GGWNSZ.mjs';
import { StyledField } from './chunk-GGGOLKUF.mjs';
import { useCurrentLocale, getCurrentTime } from './chunk-KHLKL74E.mjs';
import { useFormControlContext } from '@chakra-ui/react';
import { IconButton } from '@vygruppen/spor-button-react';
import { createTexts, useTranslation } from '@vygruppen/spor-i18n-react';
import { DropdownLeftFill24Icon, DropdownRightFill24Icon } from '@vygruppen/spor-icon-react';
import React from 'react';
import { useTimeFieldState } from 'react-stately';

var TimePicker = ({
  label: externalLabel,
  value,
  defaultValue = getCurrentTime(),
  onChange = () => {
  },
  minuteInterval = 30,
  isDisabled: isDisabledExternally = false,
  name,
  ...boxProps
}) => {
  const { isDisabled: isFormControlDisabled, isInvalid: isFormControlInvalid } = useFormControlContext() ?? {};
  const isDisabled = isDisabledExternally ?? isFormControlDisabled ?? false;
  const { t } = useTranslation();
  const locale = useCurrentLocale();
  const label = externalLabel ?? t(texts.time);
  const state = useTimeFieldState({
    value,
    defaultValue,
    onChange,
    locale,
    isDisabled,
    label,
    validationState: isFormControlInvalid ? "invalid" : "valid"
  });
  const dateTime = state.value;
  const handleBackwardsClick = () => {
    if (!dateTime) {
      return;
    }
    const minutesToSubtract = dateTime.minute % minuteInterval || minuteInterval;
    state.setValue(
      state.value.subtract({
        minutes: minutesToSubtract
      })
    );
  };
  const handleForwardClick = () => {
    if (!dateTime) {
      return;
    }
    const minutesToAdd = minuteInterval - dateTime.minute % minuteInterval || minuteInterval;
    state.setValue(
      state.value.add({
        minutes: minutesToAdd
      })
    );
  };
  const backwardsLabel = `${t(texts.backwards)} ${minuteInterval} ${t(
    texts.minutes
  )}`;
  const forwardsLabel = `${t(texts.forwards)} ${minuteInterval} ${t(
    texts.minutes
  )}`;
  const inputLabel = label ?? t(texts.time);
  const ariaLabel = `${inputLabel} \u2013 ${t(
    texts.selectedTimeIs(`${(dateTime == null ? void 0 : dateTime.hour) ?? 0} ${(dateTime == null ? void 0 : dateTime.minute) ?? 0}`)
  )}`;
  return /* @__PURE__ */ React.createElement(
    StyledField,
    {
      variant: "simple",
      width: "fit-content",
      paddingX: 2,
      paddingY: 1,
      alignItems: "center",
      justifyContent: "space-between",
      gap: 2,
      opacity: isDisabled ? 0.5 : 1,
      pointerEvents: isDisabled ? "none" : "auto",
      "aria-disabled": isDisabled,
      "aria-live": "assertive",
      "aria-label": ariaLabel,
      ...boxProps
    },
    /* @__PURE__ */ React.createElement(
      IconButton,
      {
        variant: "ghost",
        size: "xs",
        borderRadius: "xs",
        "aria-label": backwardsLabel,
        title: backwardsLabel,
        icon: /* @__PURE__ */ React.createElement(DropdownLeftFill24Icon, null),
        onClick: handleBackwardsClick,
        isDisabled,
        style: isDisabled ? { backgroundColor: "transparent" } : {}
      }
    ),
    /* @__PURE__ */ React.createElement(TimeField, { label, state, name }),
    /* @__PURE__ */ React.createElement(
      IconButton,
      {
        variant: "ghost",
        size: "xs",
        borderRadius: "xs",
        "aria-label": forwardsLabel,
        title: forwardsLabel,
        icon: /* @__PURE__ */ React.createElement(DropdownRightFill24Icon, null),
        onClick: handleForwardClick,
        isDisabled,
        style: isDisabled ? { backgroundColor: "transparent" } : {}
      }
    )
  );
};
var texts = createTexts({
  selectedTimeIs: (time) => ({
    nb: `Valgt tidspunkt er ${time}`,
    nn: `Valt tidspunkt er ${time}`,
    en: `Selected time is ${time}`,
    sv: `Vald tid \xE4r ${time}`
  }),
  time: {
    nb: "Tid",
    nn: "Tid",
    en: "Time",
    sv: "Tid"
  },
  backwards: {
    nb: "Bakover",
    nn: "Bakover",
    en: "Backwards",
    sv: "Bak\xE5t"
  },
  forwards: {
    nb: "Fremover",
    nn: "Fremover",
    en: "Forward",
    sv: "Fram\xE5t"
  },
  minutes: {
    nb: "minutter",
    nn: "minuttar",
    en: "minutes",
    sv: "minuter"
  }
});

export { TimePicker };
